# Generated by Django 5.0 on 2024-01-25 05:33

import django.db.models.deletion
from django.db import migrations, models


class Migration(migrations.Migration):
    dependencies = [
        ("intecomm_consent", "0020_auto_20240111_0115"),
        ("sites", "0002_alter_domain_unique"),
    ]

    operations = [
        migrations.RemoveField(
            model_name="subjectreconsent",
            name="action_item",
        ),
        migrations.RemoveField(
            model_name="subjectreconsent",
            name="parent_action_item",
        ),
        migrations.RemoveField(
            model_name="subjectreconsent",
            name="related_action_item",
        ),
        migrations.RemoveField(
            model_name="subjectreconsent",
            name="site",
        ),
        migrations.AlterField(
            model_name="historicalsubjectconsent",
            name="site",
            field=models.ForeignKey(
                blank=True,
                db_constraint=False,
                null=True,
                on_delete=django.db.models.deletion.DO_NOTHING,
                related_name="+",
                to="sites.site",
            ),
        ),
        migrations.AlterField(
            model_name="historicalsubjectconsentug",
            name="site",
            field=models.ForeignKey(
                blank=True,
                db_constraint=False,
                null=True,
                on_delete=django.db.models.deletion.DO_NOTHING,
                related_name="+",
                to="sites.site",
            ),
        ),
        migrations.AlterField(
            model_name="subjectconsent",
            name="site",
            field=models.ForeignKey(
                null=True,
                on_delete=django.db.models.deletion.PROTECT,
                related_name="+",
                to="sites.site",
            ),
        ),
        migrations.DeleteModel(
            name="HistoricalSubjectReconsent",
        ),
        migrations.DeleteModel(
            name="SubjectReconsent",
        ),
    ]
